==> haskell-filepattern-0.1.3-207-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-filepattern.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 filepattern
version:              0.1.3
visibility:           public
id:                   filepattern-0.1.3-EUtgvPxIjh79cTL2VL2idb
key:                  filepattern-0.1.3-EUtgvPxIjh79cTL2VL2idb
license:              BSD-3-Clause
copyright:            Neil Mitchell 2011-2022
maintainer:           Neil Mitchell <ndmitchell@gmail.com>
author:
    Neil Mitchell <ndmitchell@gmail.com>, Evan Rutledge Borden <evan@evan-borden.com>

homepage:             https://github.com/ndmitchell/filepattern#readme
synopsis:             File path glob-like matching
description:
    A library for matching files using patterns such as @\"src\/**\/*.png\"@ for all @.png@ files
    recursively under the @src@ directory. Features:

    * All matching is /O(n)/. Most functions precompute some information given only one argument.

    * See "System.FilePattern" and @?==@ simple matching and semantics.

    * Use @match@ and @substitute@ to extract suitable
    strings from the @*@ and @**@ matches, and substitute them back into other patterns.

    * Use @step@ and @matchMany@ to perform bulk matching
    of many patterns against many paths simultaneously.

    * Use "System.FilePattern.Directory" to perform optimised directory traverals using patterns.

    Originally taken from the <https://hackage.haskell.org/package/shake Shake library>.

category:             Development, FilePath
abi:                  b7694f2cee2cebd19825f42b03929f14
exposed:              True
exposed-modules:      System.FilePattern System.FilePattern.Directory
hidden-modules:
    System.FilePattern.Core System.FilePattern.ListBy
    System.FilePattern.Monads System.FilePattern.Step
    System.FilePattern.Tree System.FilePattern.Wildcard

import-dirs:          /usr/lib/ghc-9.4.8/site-local/filepattern-0.1.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/filepattern-0.1.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/filepattern-0.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-filepattern
hs-libraries:         HSfilepattern-0.1.3-EUtgvPxIjh79cTL2VL2idb
depends:
    base-4.17.2.1 directory-1.3.7.1 extra-1.7.16-74Y9X6JFoGGAtiav1DDKW7
    filepath-1.4.2.2

haddock-interfaces:   /usr/share/doc/haskell-filepattern/html/filepattern.haddock
haddock-html:         /usr/share/doc/haskell-filepattern/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-filepattern-0.1.3-208-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-filepattern.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 filepattern
version:              0.1.3
visibility:           public
id:                   filepattern-0.1.3-3E5KoaXvEIEJAFbYe2MSg2
key:                  filepattern-0.1.3-3E5KoaXvEIEJAFbYe2MSg2
license:              BSD-3-Clause
copyright:            Neil Mitchell 2011-2022
maintainer:           Neil Mitchell <ndmitchell@gmail.com>
author:
    Neil Mitchell <ndmitchell@gmail.com>, Evan Rutledge Borden <evan@evan-borden.com>

homepage:             https://github.com/ndmitchell/filepattern#readme
synopsis:             File path glob-like matching
description:
    A library for matching files using patterns such as @\"src\/**\/*.png\"@ for all @.png@ files
    recursively under the @src@ directory. Features:

    * All matching is /O(n)/. Most functions precompute some information given only one argument.

    * See "System.FilePattern" and @?==@ simple matching and semantics.

    * Use @match@ and @substitute@ to extract suitable
    strings from the @*@ and @**@ matches, and substitute them back into other patterns.

    * Use @step@ and @matchMany@ to perform bulk matching
    of many patterns against many paths simultaneously.

    * Use "System.FilePattern.Directory" to perform optimised directory traverals using patterns.

    Originally taken from the <https://hackage.haskell.org/package/shake Shake library>.

category:             Development, FilePath
abi:                  dff3f88a28bd41a3826a43814348de72
exposed:              True
exposed-modules:      System.FilePattern System.FilePattern.Directory
hidden-modules:
    System.FilePattern.Core System.FilePattern.ListBy
    System.FilePattern.Monads System.FilePattern.Step
    System.FilePattern.Tree System.FilePattern.Wildcard

import-dirs:          /usr/lib/ghc-9.4.8/site-local/filepattern-0.1.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/filepattern-0.1.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/filepattern-0.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-filepattern
hs-libraries:         HSfilepattern-0.1.3-3E5KoaXvEIEJAFbYe2MSg2
depends:
    base-4.17.2.1 directory-1.3.7.1 extra-1.7.16-FVFc4gt4avs4Z4Fwytd6v6
    filepath-1.4.2.2

haddock-interfaces:   /usr/share/doc/haskell-filepattern/html/filepattern.haddock
haddock-html:         /usr/share/doc/haskell-filepattern/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
